@@ -6,6 +6,7 @@ from fastapi.routing import APIRoute
 from typing import Callable
 
 from magicapi.Models.Call import make_call_from_request_and_response
+from magicapi.Models.task_executor import save_tasks
 
 
 class MagicCallLogger(APIRoute):
@@ -31,6 +32,7 @@ class MagicCallLogger(APIRoute):
             }
             await make_call_from_request_and_response(request, response, error, times)
             if error:
+                save_tasks()
                 raise error
             return response
 
